@@ -2,7 +2,7 @@ package analogize;
 # ABSTRACT: classify data with AM from the command line
 use strict;
 use warnings;
-our $VERSION = '3.07';
+our $VERSION = '3.08';
 use 5.010;
 use Carp;
 use Algorithm::AM::Batch;
@@ -23,6 +23,9 @@ sub _run {
         'project:s',
         'test:s',
         'print:s',
+        'include_given',
+        'include_nulls',
+        'linear',
         'help|?',
     ) or pod2usage(2);
     _validate_args(%args);
@@ -60,8 +63,12 @@ sub _run {
 
     my $count = 0;
     my $batch = Algorithm::AM::Batch->new(
+        linear => $args{linear},
+        exclude_given => !$args{include_given},
+        exclude_nulls => !$args{include_nulls},
+
         training_set => $train,
-        # print the result of each classification as they are provided
+        # print the result of each classification at the time it is provided
         end_test_hook => sub {
             my ($batch, $test_item, $result) = @_;
             ++$count if $result->result eq 'correct';
@@ -131,7 +138,7 @@ analogize - classify data with AM from the command line
 
 =head1 VERSION
 
-version 3.07
+version 3.08
 
 =head1 SYNOPSIS
 
@@ -155,6 +162,7 @@ option.
 =item B<format>
 
 specify either commas or nocommas format for exemplar and test data files
+(C<=> should be used for "null" variables).
 
 =item B<exemplars>, B<data> or B<train>
 
@@ -177,6 +185,22 @@ gang_summary, and gang_detailed. See documentation in
 L<Algorithm::AM::Result> for details (gang_detailed is gang_summary
 with list printing on).
 
+=item B<include_given>
+
+Allow a test item to be included in the data set during classification.
+If false (default), test items will be removed from the dataset during
+classification.
+
+=item B<include_nulls>
+
+Treat null variables in a test item as regular variables. If false (default),
+these variables will be excluded and not considered during classification.
+
+=item B<linear>
+
+Calculate scores using I<occurrences> (linearly) instead of using I<pointers>
+(quadratically).
+
 =item B<help> or B<?>
 
 print help message
