@@ -1,7 +1,7 @@
 package Algorithm::AM;
 use strict;
 use warnings;
-our $VERSION = '3.07';
+our $VERSION = '3.08';
 # ABSTRACT: Classify data with Analogical Modeling
 use feature 'state';
 use Carp;
@@ -327,7 +327,7 @@ Algorithm::AM - Classify data with Analogical Modeling
 
 =head1 VERSION
 
-version 3.07
+version 3.08
 
 =head1 SYNOPSIS
 
@@ -540,7 +540,7 @@ Theron Sanford <shixilun@yahoo.com>, Nathan Glenn <garfieldnate@gmail.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords garfieldnate Nathan Glenn Nick
+=for stopwords garfieldnate Nathan Glenn Nick Logan
 
 =over 4
 
@@ -554,7 +554,7 @@ Nathan Glenn <garfieldnate@gmail.com>
 
 =item *
 
-Nick <nlogan@gmail.com>
+Nick Logan <nlogan@gmail.com>
 
 =back
 
